logger

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 8, 2019 License: GPL-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package logger creates structured and colored log messages

Index

Constants

This section is empty.

Variables

Arguments is the variable were the arguments parsed by cobra module will be passed on to the logger module

var Build string

Build is where the program's build type is passed from main package

var ExecutionStartTime = time.Now()

ExecutionStartTime is the time variable that holds the time at which we finished parsing the command line arguments

var Version string

Version is where the program's version is passed from the main package

Functions

func Command

func Command(command string)

Command message will log a message that shows a command

func Fatal

func Fatal(message string)

Fatal logs an error message

func Info

func Info(message string)

Info function will log an info message

func PrintApp

func PrintApp()

PrintApp is the function that prints the app name and it's version

func PrintElapsedTime

func PrintElapsedTime()

PrintElapsedTime is the function that prints how much time was taken

Types

This section is empty.

Jump to