Documentation
¶
Overview ¶
Package logger creates structured and colored log messages
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Arguments = constants.ArgumentSkeleton{}
Arguments is the variable were the arguments parsed by cobra module will be passed on to the logger module
var Build string
Build is where the program's build type is passed from main package
var ExecutionStartTime = time.Now()
ExecutionStartTime is the time variable that holds the time at which we finished parsing the command line arguments
var Version string
Version is where the program's version is passed from the main package
Functions ¶
func PrintElapsedTime ¶
func PrintElapsedTime()
PrintElapsedTime is the function that prints how much time was taken
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.